import reflex as rx

class Fa42Group(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa42Group"


class Fa500Px(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa500Px"


class FaAccessibleIcon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAccessibleIcon"


class FaAccusoft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAccusoft"


class FaAdn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAdn"


class FaAdversal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAdversal"


class FaAffiliatetheme(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAffiliatetheme"


class FaAirbnb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAirbnb"


class FaAlgolia(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlgolia"


class FaAlipay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlipay"


class FaAmazonPay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAmazonPay"


class FaAmazon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAmazon"


class FaAmilia(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAmilia"


class FaAndroid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAndroid"


class FaAngellist(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngellist"


class FaAngrycreative(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngrycreative"


class FaAngular(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngular"


class FaAppStoreIos(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAppStoreIos"


class FaAppStore(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAppStore"


class FaApper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaApper"


class FaApplePay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaApplePay"


class FaApple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaApple"


class FaArtstation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArtstation"


class FaAsymmetrik(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAsymmetrik"


class FaAtlassian(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAtlassian"


class FaAudible(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAudible"


class FaAutoprefixer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAutoprefixer"


class FaAvianex(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAvianex"


class FaAviato(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAviato"


class FaAws(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAws"


class FaBandcamp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBandcamp"


class FaBattleNet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBattleNet"


class FaBehance(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBehance"


class FaBilibili(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBilibili"


class FaBimobject(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBimobject"


class FaBitbucket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBitbucket"


class FaBitcoin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBitcoin"


class FaBity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBity"


class FaBlackTie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlackTie"


class FaBlackberry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlackberry"


class FaBloggerB(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBloggerB"


class FaBlogger(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlogger"


class FaBluetoothB(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBluetoothB"


class FaBluetooth(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBluetooth"


class FaBootstrap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBootstrap"


class FaBots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBots"


class FaBtc(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBtc"


class FaBuffer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuffer"


class FaBuromobelexperte(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuromobelexperte"


class FaBuyNLarge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuyNLarge"


class FaBuysellads(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuysellads"


class FaCanadianMapleLeaf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCanadianMapleLeaf"


class FaCcAmazonPay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcAmazonPay"


class FaCcAmex(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcAmex"


class FaCcApplePay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcApplePay"


class FaCcDinersClub(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcDinersClub"


class FaCcDiscover(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcDiscover"


class FaCcJcb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcJcb"


class FaCcMastercard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcMastercard"


class FaCcPaypal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcPaypal"


class FaCcStripe(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcStripe"


class FaCcVisa(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCcVisa"


class FaCentercode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCentercode"


class FaCentos(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCentos"


class FaChrome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChrome"


class FaChromecast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChromecast"


class FaCloudflare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudflare"


class FaCloudscale(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudscale"


class FaCloudsmith(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudsmith"


class FaCloudversify(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudversify"


class FaCmplid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCmplid"


class FaCodepen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodepen"


class FaCodiepie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodiepie"


class FaConfluence(rx.Component):
    library = "react-icons/fa6"
    tag = "FaConfluence"


class FaConnectdevelop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaConnectdevelop"


class FaContao(rx.Component):
    library = "react-icons/fa6"
    tag = "FaContao"


class FaCottonBureau(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCottonBureau"


class FaCpanel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCpanel"


class FaCreativeCommonsBy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsBy"


class FaCreativeCommonsNcEu(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsNcEu"


class FaCreativeCommonsNcJp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsNcJp"


class FaCreativeCommonsNc(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsNc"


class FaCreativeCommonsNd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsNd"


class FaCreativeCommonsPdAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsPdAlt"


class FaCreativeCommonsPd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsPd"


class FaCreativeCommonsRemix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsRemix"


class FaCreativeCommonsSa(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsSa"


class FaCreativeCommonsSamplingPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsSamplingPlus"


class FaCreativeCommonsSampling(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsSampling"


class FaCreativeCommonsShare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsShare"


class FaCreativeCommonsZero(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommonsZero"


class FaCreativeCommons(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreativeCommons"


class FaCriticalRole(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCriticalRole"


class FaCss3Alt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCss3Alt"


class FaCss3(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCss3"


class FaCuttlefish(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCuttlefish"


class FaDAndDBeyond(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDAndDBeyond"


class FaDAndD(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDAndD"


class FaDailymotion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDailymotion"


class FaDashcube(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDashcube"


class FaDeezer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDeezer"


class FaDelicious(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDelicious"


class FaDeploydog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDeploydog"


class FaDeskpro(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDeskpro"


class FaDev(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDev"


class FaDeviantart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDeviantart"


class FaDhl(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDhl"


class FaDiaspora(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiaspora"


class FaDigg(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDigg"


class FaDigitalOcean(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDigitalOcean"


class FaDiscord(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiscord"


class FaDiscourse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiscourse"


class FaDochub(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDochub"


class FaDocker(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDocker"


class FaDraft2Digital(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDraft2Digital"


class FaDribbble(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDribbble"


class FaDropbox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDropbox"


class FaDrupal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDrupal"


class FaDyalog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDyalog"


class FaEarlybirds(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarlybirds"


class FaEbay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEbay"


class FaEdgeLegacy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEdgeLegacy"


class FaEdge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEdge"


class FaElementor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaElementor"


class FaEllo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEllo"


class FaEmber(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEmber"


class FaEmpire(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEmpire"


class FaEnvira(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvira"


class FaErlang(rx.Component):
    library = "react-icons/fa6"
    tag = "FaErlang"


class FaEthereum(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEthereum"


class FaEtsy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEtsy"


class FaEvernote(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEvernote"


class FaExpeditedssl(rx.Component):
    library = "react-icons/fa6"
    tag = "FaExpeditedssl"


class FaFacebookF(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFacebookF"


class FaFacebookMessenger(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFacebookMessenger"


class FaFacebook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFacebook"


class FaFantasyFlightGames(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFantasyFlightGames"


class FaFedex(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFedex"


class FaFedora(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFedora"


class FaFigma(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFigma"


class FaFirefoxBrowser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFirefoxBrowser"


class FaFirefox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFirefox"


class FaFirstOrderAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFirstOrderAlt"


class FaFirstOrder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFirstOrder"


class FaFirstdraft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFirstdraft"


class FaFlickr(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlickr"


class FaFlipboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlipboard"


class FaFly(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFly"


class FaFontAwesome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFontAwesome"


class FaFonticonsFi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFonticonsFi"


class FaFonticons(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFonticons"


class FaFortAwesomeAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFortAwesomeAlt"


class FaFortAwesome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFortAwesome"


class FaForumbee(rx.Component):
    library = "react-icons/fa6"
    tag = "FaForumbee"


class FaFoursquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFoursquare"


class FaFreeCodeCamp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFreeCodeCamp"


class FaFreebsd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFreebsd"


class FaFulcrum(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFulcrum"


class FaGalacticRepublic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGalacticRepublic"


class FaGalacticSenate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGalacticSenate"


class FaGetPocket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGetPocket"


class FaGgCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGgCircle"


class FaGg(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGg"


class FaGitAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGitAlt"


class FaGit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGit"


class FaGithubAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGithubAlt"


class FaGithub(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGithub"


class FaGitkraken(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGitkraken"


class FaGitlab(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGitlab"


class FaGitter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGitter"


class FaGlideG(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlideG"


class FaGlide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlide"


class FaGofore(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGofore"


class FaGolang(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGolang"


class FaGoodreadsG(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGoodreadsG"


class FaGoodreads(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGoodreads"


class FaGoogleDrive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGoogleDrive"


class FaGooglePay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGooglePay"


class FaGooglePlay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGooglePlay"


class FaGooglePlusG(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGooglePlusG"


class FaGooglePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGooglePlus"


class FaGoogleWallet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGoogleWallet"


class FaGoogle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGoogle"


class FaGratipay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGratipay"


class FaGrav(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGrav"


class FaGripfire(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGripfire"


class FaGrunt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGrunt"


class FaGuilded(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGuilded"


class FaGulp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGulp"


class FaHackerNews(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHackerNews"


class FaHackerrank(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHackerrank"


class FaHashnode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHashnode"


class FaHips(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHips"


class FaHireAHelper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHireAHelper"


class FaHive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHive"


class FaHooli(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHooli"


class FaHornbill(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHornbill"


class FaHotjar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHotjar"


class FaHouzz(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouzz"


class FaHtml5(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHtml5"


class FaHubspot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHubspot"


class FaIdeal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIdeal"


class FaImdb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaImdb"


class FaInstagram(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInstagram"


class FaInstalod(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInstalod"


class FaIntercom(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIntercom"


class FaInternetExplorer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInternetExplorer"


class FaInvision(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInvision"


class FaIoxhost(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIoxhost"


class FaItchIo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaItchIo"


class FaItunesNote(rx.Component):
    library = "react-icons/fa6"
    tag = "FaItunesNote"


class FaItunes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaItunes"


class FaJava(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJava"


class FaJediOrder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJediOrder"


class FaJenkins(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJenkins"


class FaJira(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJira"


class FaJoget(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJoget"


class FaJoomla(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJoomla"


class FaJs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJs"


class FaJsfiddle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJsfiddle"


class FaKaggle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKaggle"


class FaKeybase(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKeybase"


class FaKeycdn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKeycdn"


class FaKickstarterK(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKickstarterK"


class FaKickstarter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKickstarter"


class FaKorvue(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKorvue"


class FaLaravel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLaravel"


class FaLastfm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLastfm"


class FaLeanpub(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLeanpub"


class FaLess(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLess"


class FaLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLine"


class FaLinkedinIn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinkedinIn"


class FaLinkedin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinkedin"


class FaLinode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinode"


class FaLinux(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinux"


class FaLyft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLyft"


class FaMagento(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagento"


class FaMailchimp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMailchimp"


class FaMandalorian(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMandalorian"


class FaMarkdown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarkdown"


class FaMastodon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMastodon"


class FaMaxcdn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMaxcdn"


class FaMdb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMdb"


class FaMedapps(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMedapps"


class FaMedium(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMedium"


class FaMedrt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMedrt"


class FaMeetup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMeetup"


class FaMegaport(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMegaport"


class FaMendeley(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMendeley"


class FaMeta(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMeta"


class FaMicroblog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicroblog"


class FaMicrosoft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrosoft"


class FaMix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMix"


class FaMixcloud(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMixcloud"


class FaMixer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMixer"


class FaMizuni(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMizuni"


class FaModx(rx.Component):
    library = "react-icons/fa6"
    tag = "FaModx"


class FaMonero(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMonero"


class FaNapster(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNapster"


class FaNeos(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNeos"


class FaNfcDirectional(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNfcDirectional"


class FaNfcSymbol(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNfcSymbol"


class FaNimblr(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNimblr"


class FaNodeJs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNodeJs"


class FaNode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNode"


class FaNpm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNpm"


class FaNs8(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNs8"


class FaNutritionix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNutritionix"


class FaOctopusDeploy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOctopusDeploy"


class FaOdnoklassniki(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOdnoklassniki"


class FaOdysee(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOdysee"


class FaOldRepublic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOldRepublic"


class FaOpencart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOpencart"


class FaOpenid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOpenid"


class FaOpera(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOpera"


class FaOptinMonster(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOptinMonster"


class FaOrcid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOrcid"


class FaOsi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOsi"


class FaPadlet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPadlet"


class FaPage4(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPage4"


class FaPagelines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPagelines"


class FaPalfed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPalfed"


class FaPatreon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPatreon"


class FaPaypal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaypal"


class FaPerbyte(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPerbyte"


class FaPeriscope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeriscope"


class FaPhabricator(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhabricator"


class FaPhoenixFramework(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhoenixFramework"


class FaPhoenixSquadron(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhoenixSquadron"


class FaPhp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhp"


class FaPiedPiperAlt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPiedPiperAlt"


class FaPiedPiperHat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPiedPiperHat"


class FaPiedPiperPp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPiedPiperPp"


class FaPiedPiper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPiedPiper"


class FaPinterestP(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPinterestP"


class FaPinterest(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPinterest"


class FaPix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPix"


class FaPlaystation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaystation"


class FaProductHunt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaProductHunt"


class FaPushed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPushed"


class FaPython(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPython"


class FaQq(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQq"


class FaQuinscape(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQuinscape"


class FaQuora(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQuora"


class FaRProject(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRProject"


class FaRaspberryPi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRaspberryPi"


class FaRavelry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRavelry"


class FaReact(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReact"


class FaReacteurope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReacteurope"


class FaReadme(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReadme"


class FaRebel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRebel"


class FaRedRiver(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRedRiver"


class FaRedditAlien(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRedditAlien"


class FaReddit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReddit"


class FaRedhat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRedhat"


class FaRenren(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRenren"


class FaReplyd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReplyd"


class FaResearchgate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaResearchgate"


class FaResolving(rx.Component):
    library = "react-icons/fa6"
    tag = "FaResolving"


class FaRev(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRev"


class FaRocketchat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRocketchat"


class FaRockrms(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRockrms"


class FaRust(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRust"


class FaSafari(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSafari"


class FaSalesforce(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSalesforce"


class FaSass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSass"


class FaSchlix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchlix"


class FaScreenpal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScreenpal"


class FaScribd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScribd"


class FaSearchengin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSearchengin"


class FaSellcast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSellcast"


class FaSellsy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSellsy"


class FaServicestack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaServicestack"


class FaShirtsinbulk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShirtsinbulk"


class FaShopify(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShopify"


class FaShopware(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShopware"


class FaSimplybuilt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSimplybuilt"


class FaSistrix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSistrix"


class FaSith(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSith"


class FaSitrox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSitrox"


class FaSketch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSketch"


class FaSkyatlas(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSkyatlas"


class FaSkype(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSkype"


class FaSlack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSlack"


class FaSlideshare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSlideshare"


class FaSnapchat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSnapchat"


class FaSoundcloud(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSoundcloud"


class FaSourcetree(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSourcetree"


class FaSpaceAwesome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpaceAwesome"


class FaSpeakap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpeakap"


class FaSpeakerDeck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpeakerDeck"


class FaSpotify(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpotify"


class FaSquareBehance(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareBehance"


class FaSquareDribbble(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareDribbble"


class FaSquareFacebook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareFacebook"


class FaSquareFontAwesomeStroke(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareFontAwesomeStroke"


class FaSquareFontAwesome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareFontAwesome"


class FaSquareGit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareGit"


class FaSquareGithub(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareGithub"


class FaSquareGitlab(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareGitlab"


class FaSquareGooglePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareGooglePlus"


class FaSquareHackerNews(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareHackerNews"


class FaSquareInstagram(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareInstagram"


class FaSquareJs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareJs"


class FaSquareLastfm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareLastfm"


class FaSquareOdnoklassniki(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareOdnoklassniki"


class FaSquarePiedPiper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePiedPiper"


class FaSquarePinterest(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePinterest"


class FaSquareReddit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareReddit"


class FaSquareSnapchat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareSnapchat"


class FaSquareSteam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareSteam"


class FaSquareTumblr(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareTumblr"


class FaSquareTwitter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareTwitter"


class FaSquareViadeo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareViadeo"


class FaSquareVimeo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareVimeo"


class FaSquareWhatsapp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareWhatsapp"


class FaSquareXing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareXing"


class FaSquareYoutube(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareYoutube"


class FaSquarespace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarespace"


class FaStackExchange(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStackExchange"


class FaStackOverflow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStackOverflow"


class FaStackpath(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStackpath"


class FaStaylinked(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStaylinked"


class FaSteamSymbol(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSteamSymbol"


class FaSteam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSteam"


class FaStickerMule(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStickerMule"


class FaStrava(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStrava"


class FaStripeS(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStripeS"


class FaStripe(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStripe"


class FaStubber(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStubber"


class FaStudiovinari(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStudiovinari"


class FaStumbleuponCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStumbleuponCircle"


class FaStumbleupon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStumbleupon"


class FaSuperpowers(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuperpowers"


class FaSupple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSupple"


class FaSuse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuse"


class FaSwift(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSwift"


class FaSymfony(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSymfony"


class FaTeamspeak(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTeamspeak"


class FaTelegram(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTelegram"


class FaTencentWeibo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTencentWeibo"


class FaTheRedYeti(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTheRedYeti"


class FaThemeco(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThemeco"


class FaThemeisle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThemeisle"


class FaThinkPeaks(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThinkPeaks"


class FaTiktok(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTiktok"


class FaTradeFederation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTradeFederation"


class FaTrello(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrello"


class FaTumblr(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTumblr"


class FaTwitch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTwitch"


class FaTwitter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTwitter"


class FaTypo3(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTypo3"


class FaUber(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUber"


class FaUbuntu(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUbuntu"


class FaUikit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUikit"


class FaUmbraco(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUmbraco"


class FaUncharted(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUncharted"


class FaUniregistry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUniregistry"


class FaUnity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUnity"


class FaUnsplash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUnsplash"


class FaUntappd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUntappd"


class FaUps(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUps"


class FaUsb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsb"


class FaUsps(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsps"


class FaUssunnah(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUssunnah"


class FaVaadin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVaadin"


class FaViacoin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaViacoin"


class FaViadeo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaViadeo"


class FaViber(rx.Component):
    library = "react-icons/fa6"
    tag = "FaViber"


class FaVimeoV(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVimeoV"


class FaVimeo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVimeo"


class FaVine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVine"


class FaVk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVk"


class FaVnv(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVnv"


class FaVuejs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVuejs"


class FaWatchmanMonitoring(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWatchmanMonitoring"


class FaWaze(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWaze"


class FaWeebly(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWeebly"


class FaWeibo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWeibo"


class FaWeixin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWeixin"


class FaWhatsapp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWhatsapp"


class FaWhmcs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWhmcs"


class FaWikipediaW(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWikipediaW"


class FaWindows(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWindows"


class FaWirsindhandwerk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWirsindhandwerk"


class FaWix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWix"


class FaWizardsOfTheCoast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWizardsOfTheCoast"


class FaWodu(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWodu"


class FaWolfPackBattalion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWolfPackBattalion"


class FaWordpressSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWordpressSimple"


class FaWordpress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWordpress"


class FaWpbeginner(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWpbeginner"


class FaWpexplorer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWpexplorer"


class FaWpforms(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWpforms"


class FaWpressr(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWpressr"


class FaXbox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaXbox"


class FaXing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaXing"


class FaYCombinator(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYCombinator"


class FaYahoo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYahoo"


class FaYammer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYammer"


class FaYandexInternational(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYandexInternational"


class FaYandex(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYandex"


class FaYarn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYarn"


class FaYelp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYelp"


class FaYoast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYoast"


class FaYoutube(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYoutube"


class FaZhihu(rx.Component):
    library = "react-icons/fa6"
    tag = "FaZhihu"


class Fa0(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa0"


class Fa1(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa1"


class Fa2(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa2"


class Fa3(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa3"


class Fa4(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa4"


class Fa5(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa5"


class Fa6(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa6"


class Fa7(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa7"


class Fa8(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa8"


class Fa9(rx.Component):
    library = "react-icons/fa6"
    tag = "Fa9"


class FaA(rx.Component):
    library = "react-icons/fa6"
    tag = "FaA"


class FaAddressBook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAddressBook"


class FaAddressCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAddressCard"


class FaAlignCenter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlignCenter"


class FaAlignJustify(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlignJustify"


class FaAlignLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlignLeft"


class FaAlignRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAlignRight"


class FaAnchorCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnchorCircleCheck"


class FaAnchorCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnchorCircleExclamation"


class FaAnchorCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnchorCircleXmark"


class FaAnchorLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnchorLock"


class FaAnchor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnchor"


class FaAngleDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngleDown"


class FaAngleLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngleLeft"


class FaAngleRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngleRight"


class FaAngleUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAngleUp"


class FaAnglesDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnglesDown"


class FaAnglesLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnglesLeft"


class FaAnglesRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnglesRight"


class FaAnglesUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnglesUp"


class FaAnkh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAnkh"


class FaAppleWhole(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAppleWhole"


class FaArchway(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArchway"


class FaArrowDown19(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDown19"


class FaArrowDown91(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDown91"


class FaArrowDownAZ(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownAZ"


class FaArrowDownLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownLong"


class FaArrowDownShortWide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownShortWide"


class FaArrowDownUpAcrossLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownUpAcrossLine"


class FaArrowDownUpLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownUpLock"


class FaArrowDownWideShort(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownWideShort"


class FaArrowDownZA(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDownZA"


class FaArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowDown"


class FaArrowLeftLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowLeftLong"


class FaArrowLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowLeft"


class FaArrowPointer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowPointer"


class FaArrowRightArrowLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRightArrowLeft"


class FaArrowRightFromBracket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRightFromBracket"


class FaArrowRightLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRightLong"


class FaArrowRightToBracket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRightToBracket"


class FaArrowRightToCity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRightToCity"


class FaArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRight"


class FaArrowRotateLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRotateLeft"


class FaArrowRotateRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowRotateRight"


class FaArrowTrendDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowTrendDown"


class FaArrowTrendUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowTrendUp"


class FaArrowTurnDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowTurnDown"


class FaArrowTurnUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowTurnUp"


class FaArrowUp19(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUp19"


class FaArrowUp91(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUp91"


class FaArrowUpAZ(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpAZ"


class FaArrowUpFromBracket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpFromBracket"


class FaArrowUpFromGroundWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpFromGroundWater"


class FaArrowUpFromWaterPump(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpFromWaterPump"


class FaArrowUpLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpLong"


class FaArrowUpRightDots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpRightDots"


class FaArrowUpRightFromSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpRightFromSquare"


class FaArrowUpShortWide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpShortWide"


class FaArrowUpWideShort(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpWideShort"


class FaArrowUpZA(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUpZA"


class FaArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowUp"


class FaArrowsDownToLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsDownToLine"


class FaArrowsDownToPeople(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsDownToPeople"


class FaArrowsLeftRightToLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsLeftRightToLine"


class FaArrowsLeftRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsLeftRight"


class FaArrowsRotate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsRotate"


class FaArrowsSpin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsSpin"


class FaArrowsSplitUpAndLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsSplitUpAndLeft"


class FaArrowsToCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsToCircle"


class FaArrowsToDot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsToDot"


class FaArrowsToEye(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsToEye"


class FaArrowsTurnRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsTurnRight"


class FaArrowsTurnToDots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsTurnToDots"


class FaArrowsUpDownLeftRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsUpDownLeftRight"


class FaArrowsUpDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsUpDown"


class FaArrowsUpToLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaArrowsUpToLine"


class FaAsterisk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAsterisk"


class FaAt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAt"


class FaAtom(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAtom"


class FaAudioDescription(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAudioDescription"


class FaAustralSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAustralSign"


class FaAward(rx.Component):
    library = "react-icons/fa6"
    tag = "FaAward"


class FaB(rx.Component):
    library = "react-icons/fa6"
    tag = "FaB"


class FaBabyCarriage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBabyCarriage"


class FaBaby(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBaby"


class FaBackwardFast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBackwardFast"


class FaBackwardStep(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBackwardStep"


class FaBackward(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBackward"


class FaBacon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBacon"


class FaBacteria(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBacteria"


class FaBacterium(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBacterium"


class FaBagShopping(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBagShopping"


class FaBahai(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBahai"


class FaBahtSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBahtSign"


class FaBanSmoking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBanSmoking"


class FaBan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBan"


class FaBandage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBandage"


class FaBangladeshiTakaSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBangladeshiTakaSign"


class FaBarcode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBarcode"


class FaBarsProgress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBarsProgress"


class FaBarsStaggered(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBarsStaggered"


class FaBars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBars"


class FaBaseballBatBall(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBaseballBatBall"


class FaBaseball(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBaseball"


class FaBasketShopping(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBasketShopping"


class FaBasketball(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBasketball"


class FaBath(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBath"


class FaBatteryEmpty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBatteryEmpty"


class FaBatteryFull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBatteryFull"


class FaBatteryHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBatteryHalf"


class FaBatteryQuarter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBatteryQuarter"


class FaBatteryThreeQuarters(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBatteryThreeQuarters"


class FaBedPulse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBedPulse"


class FaBed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBed"


class FaBeerMugEmpty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBeerMugEmpty"


class FaBellConcierge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBellConcierge"


class FaBellSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBellSlash"


class FaBell(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBell"


class FaBezierCurve(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBezierCurve"


class FaBicycle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBicycle"


class FaBinoculars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBinoculars"


class FaBiohazard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBiohazard"


class FaBitcoinSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBitcoinSign"


class FaBlenderPhone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlenderPhone"


class FaBlender(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlender"


class FaBlog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBlog"


class FaBold(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBold"


class FaBoltLightning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoltLightning"


class FaBolt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBolt"


class FaBomb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBomb"


class FaBone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBone"


class FaBong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBong"


class FaBookAtlas(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookAtlas"


class FaBookBible(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookBible"


class FaBookBookmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookBookmark"


class FaBookJournalWhills(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookJournalWhills"


class FaBookMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookMedical"


class FaBookOpenReader(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookOpenReader"


class FaBookOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookOpen"


class FaBookQuran(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookQuran"


class FaBookSkull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookSkull"


class FaBookTanakh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookTanakh"


class FaBook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBook"


class FaBookmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBookmark"


class FaBorderAll(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBorderAll"


class FaBorderNone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBorderNone"


class FaBorderTopLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBorderTopLeft"


class FaBoreHole(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoreHole"


class FaBottleDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBottleDroplet"


class FaBottleWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBottleWater"


class FaBowlFood(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBowlFood"


class FaBowlRice(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBowlRice"


class FaBowlingBall(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBowlingBall"


class FaBoxArchive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoxArchive"


class FaBoxOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoxOpen"


class FaBoxTissue(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoxTissue"


class FaBox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBox"


class FaBoxesPacking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoxesPacking"


class FaBoxesStacked(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBoxesStacked"


class FaBraille(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBraille"


class FaBrain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBrain"


class FaBrazilianRealSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBrazilianRealSign"


class FaBreadSlice(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBreadSlice"


class FaBridgeCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridgeCircleCheck"


class FaBridgeCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridgeCircleExclamation"


class FaBridgeCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridgeCircleXmark"


class FaBridgeLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridgeLock"


class FaBridgeWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridgeWater"


class FaBridge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBridge"


class FaBriefcaseMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBriefcaseMedical"


class FaBriefcase(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBriefcase"


class FaBroomBall(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBroomBall"


class FaBroom(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBroom"


class FaBrush(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBrush"


class FaBucket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBucket"


class FaBugSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBugSlash"


class FaBug(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBug"


class FaBugs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBugs"


class FaBuildingCircleArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingCircleArrowRight"


class FaBuildingCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingCircleCheck"


class FaBuildingCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingCircleExclamation"


class FaBuildingCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingCircleXmark"


class FaBuildingColumns(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingColumns"


class FaBuildingFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingFlag"


class FaBuildingLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingLock"


class FaBuildingNgo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingNgo"


class FaBuildingShield(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingShield"


class FaBuildingUn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingUn"


class FaBuildingUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingUser"


class FaBuildingWheat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuildingWheat"


class FaBuilding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBuilding"


class FaBullhorn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBullhorn"


class FaBullseye(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBullseye"


class FaBurger(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBurger"


class FaBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBurst"


class FaBusSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBusSimple"


class FaBus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBus"


class FaBusinessTime(rx.Component):
    library = "react-icons/fa6"
    tag = "FaBusinessTime"


class FaC(rx.Component):
    library = "react-icons/fa6"
    tag = "FaC"


class FaCableCar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCableCar"


class FaCakeCandles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCakeCandles"


class FaCalculator(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalculator"


class FaCalendarCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarCheck"


class FaCalendarDay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarDay"


class FaCalendarDays(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarDays"


class FaCalendarMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarMinus"


class FaCalendarPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarPlus"


class FaCalendarWeek(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarWeek"


class FaCalendarXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendarXmark"


class FaCalendar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCalendar"


class FaCameraRetro(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCameraRetro"


class FaCameraRotate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCameraRotate"


class FaCamera(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCamera"


class FaCampground(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCampground"


class FaCandyCane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCandyCane"


class FaCannabis(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCannabis"


class FaCapsules(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCapsules"


class FaCarBattery(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarBattery"


class FaCarBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarBurst"


class FaCarOn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarOn"


class FaCarRear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarRear"


class FaCarSide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarSide"


class FaCarTunnel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarTunnel"


class FaCar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCar"


class FaCaravan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCaravan"


class FaCaretDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCaretDown"


class FaCaretLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCaretLeft"


class FaCaretRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCaretRight"


class FaCaretUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCaretUp"


class FaCarrot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCarrot"


class FaCartArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCartArrowDown"


class FaCartFlatbedSuitcase(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCartFlatbedSuitcase"


class FaCartFlatbed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCartFlatbed"


class FaCartPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCartPlus"


class FaCartShopping(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCartShopping"


class FaCashRegister(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCashRegister"


class FaCat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCat"


class FaCediSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCediSign"


class FaCentSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCentSign"


class FaCertificate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCertificate"


class FaChair(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChair"


class FaChalkboardUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChalkboardUser"


class FaChalkboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChalkboard"


class FaChampagneGlasses(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChampagneGlasses"


class FaChargingStation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChargingStation"


class FaChartArea(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartArea"


class FaChartBar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartBar"


class FaChartColumn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartColumn"


class FaChartGantt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartGantt"


class FaChartLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartLine"


class FaChartPie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartPie"


class FaChartSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChartSimple"


class FaCheckDouble(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCheckDouble"


class FaCheckToSlot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCheckToSlot"


class FaCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCheck"


class FaCheese(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCheese"


class FaChessBishop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessBishop"


class FaChessBoard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessBoard"


class FaChessKing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessKing"


class FaChessKnight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessKnight"


class FaChessPawn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessPawn"


class FaChessQueen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessQueen"


class FaChessRook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChessRook"


class FaChess(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChess"


class FaChevronDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChevronDown"


class FaChevronLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChevronLeft"


class FaChevronRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChevronRight"


class FaChevronUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChevronUp"


class FaChildCombatant(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChildCombatant"


class FaChildDress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChildDress"


class FaChildReaching(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChildReaching"


class FaChild(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChild"


class FaChildren(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChildren"


class FaChurch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaChurch"


class FaCircleArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleArrowDown"


class FaCircleArrowLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleArrowLeft"


class FaCircleArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleArrowRight"


class FaCircleArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleArrowUp"


class FaCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleCheck"


class FaCircleChevronDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleChevronDown"


class FaCircleChevronLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleChevronLeft"


class FaCircleChevronRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleChevronRight"


class FaCircleChevronUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleChevronUp"


class FaCircleDollarToSlot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleDollarToSlot"


class FaCircleDot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleDot"


class FaCircleDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleDown"


class FaCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleExclamation"


class FaCircleH(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleH"


class FaCircleHalfStroke(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleHalfStroke"


class FaCircleInfo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleInfo"


class FaCircleLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleLeft"


class FaCircleMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleMinus"


class FaCircleNodes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleNodes"


class FaCircleNotch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleNotch"


class FaCirclePause(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCirclePause"


class FaCirclePlay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCirclePlay"


class FaCirclePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCirclePlus"


class FaCircleQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleQuestion"


class FaCircleRadiation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleRadiation"


class FaCircleRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleRight"


class FaCircleStop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleStop"


class FaCircleUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleUp"


class FaCircleUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleUser"


class FaCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircleXmark"


class FaCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCircle"


class FaCity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCity"


class FaClapperboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClapperboard"


class FaClipboardCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClipboardCheck"


class FaClipboardList(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClipboardList"


class FaClipboardQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClipboardQuestion"


class FaClipboardUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClipboardUser"


class FaClipboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClipboard"


class FaClockRotateLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClockRotateLeft"


class FaClock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClock"


class FaClone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClone"


class FaClosedCaptioning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClosedCaptioning"


class FaCloudArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudArrowDown"


class FaCloudArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudArrowUp"


class FaCloudBolt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudBolt"


class FaCloudMeatball(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudMeatball"


class FaCloudMoonRain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudMoonRain"


class FaCloudMoon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudMoon"


class FaCloudRain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudRain"


class FaCloudShowersHeavy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudShowersHeavy"


class FaCloudShowersWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudShowersWater"


class FaCloudSunRain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudSunRain"


class FaCloudSun(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloudSun"


class FaCloud(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCloud"


class FaClover(rx.Component):
    library = "react-icons/fa6"
    tag = "FaClover"


class FaCodeBranch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodeBranch"


class FaCodeCommit(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodeCommit"


class FaCodeCompare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodeCompare"


class FaCodeFork(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodeFork"


class FaCodeMerge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodeMerge"


class FaCodePullRequest(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCodePullRequest"


class FaCode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCode"


class FaCoins(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCoins"


class FaColonSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaColonSign"


class FaCommentDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentDollar"


class FaCommentDots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentDots"


class FaCommentMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentMedical"


class FaCommentSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentSlash"


class FaCommentSms(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentSms"


class FaComment(rx.Component):
    library = "react-icons/fa6"
    tag = "FaComment"


class FaCommentsDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCommentsDollar"


class FaComments(rx.Component):
    library = "react-icons/fa6"
    tag = "FaComments"


class FaCompactDisc(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCompactDisc"


class FaCompassDrafting(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCompassDrafting"


class FaCompass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCompass"


class FaCompress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCompress"


class FaComputerMouse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaComputerMouse"


class FaComputer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaComputer"


class FaCookieBite(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCookieBite"


class FaCookie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCookie"


class FaCopy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCopy"


class FaCopyright(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCopyright"


class FaCouch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCouch"


class FaCow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCow"


class FaCreditCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCreditCard"


class FaCropSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCropSimple"


class FaCrop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCrop"


class FaCross(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCross"


class FaCrosshairs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCrosshairs"


class FaCrow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCrow"


class FaCrown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCrown"


class FaCrutch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCrutch"


class FaCruzeiroSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCruzeiroSign"


class FaCube(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCube"


class FaCubesStacked(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCubesStacked"


class FaCubes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaCubes"


class FaD(rx.Component):
    library = "react-icons/fa6"
    tag = "FaD"


class FaDatabase(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDatabase"


class FaDeleteLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDeleteLeft"


class FaDemocrat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDemocrat"


class FaDesktop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDesktop"


class FaDharmachakra(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDharmachakra"


class FaDiagramNext(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiagramNext"


class FaDiagramPredecessor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiagramPredecessor"


class FaDiagramProject(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiagramProject"


class FaDiagramSuccessor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiagramSuccessor"


class FaDiamondTurnRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiamondTurnRight"


class FaDiamond(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiamond"


class FaDiceD20(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceD20"


class FaDiceD6(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceD6"


class FaDiceFive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceFive"


class FaDiceFour(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceFour"


class FaDiceOne(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceOne"


class FaDiceSix(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceSix"


class FaDiceThree(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceThree"


class FaDiceTwo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDiceTwo"


class FaDice(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDice"


class FaDisease(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDisease"


class FaDisplay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDisplay"


class FaDivide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDivide"


class FaDna(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDna"


class FaDog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDog"


class FaDollarSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDollarSign"


class FaDolly(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDolly"


class FaDongSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDongSign"


class FaDoorClosed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDoorClosed"


class FaDoorOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDoorOpen"


class FaDove(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDove"


class FaDownLeftAndUpRightToCenter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDownLeftAndUpRightToCenter"


class FaDownLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDownLong"


class FaDownload(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDownload"


class FaDragon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDragon"


class FaDrawPolygon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDrawPolygon"


class FaDropletSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDropletSlash"


class FaDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDroplet"


class FaDrumSteelpan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDrumSteelpan"


class FaDrum(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDrum"


class FaDrumstickBite(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDrumstickBite"


class FaDumbbell(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDumbbell"


class FaDumpsterFire(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDumpsterFire"


class FaDumpster(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDumpster"


class FaDungeon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaDungeon"


class FaE(rx.Component):
    library = "react-icons/fa6"
    tag = "FaE"


class FaEarDeaf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarDeaf"


class FaEarListen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarListen"


class FaEarthAfrica(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarthAfrica"


class FaEarthAmericas(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarthAmericas"


class FaEarthAsia(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarthAsia"


class FaEarthEurope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarthEurope"


class FaEarthOceania(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEarthOceania"


class FaEgg(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEgg"


class FaEject(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEject"


class FaElevator(rx.Component):
    library = "react-icons/fa6"
    tag = "FaElevator"


class FaEllipsisVertical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEllipsisVertical"


class FaEllipsis(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEllipsis"


class FaEnvelopeCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvelopeCircleCheck"


class FaEnvelopeOpenText(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvelopeOpenText"


class FaEnvelopeOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvelopeOpen"


class FaEnvelope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvelope"


class FaEnvelopesBulk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEnvelopesBulk"


class FaEquals(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEquals"


class FaEraser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEraser"


class FaEthernet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEthernet"


class FaEuroSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEuroSign"


class FaExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaExclamation"


class FaExpand(rx.Component):
    library = "react-icons/fa6"
    tag = "FaExpand"


class FaExplosion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaExplosion"


class FaEyeDropper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEyeDropper"


class FaEyeLowVision(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEyeLowVision"


class FaEyeSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEyeSlash"


class FaEye(rx.Component):
    library = "react-icons/fa6"
    tag = "FaEye"


class FaF(rx.Component):
    library = "react-icons/fa6"
    tag = "FaF"


class FaFaceAngry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceAngry"


class FaFaceDizzy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceDizzy"


class FaFaceFlushed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceFlushed"


class FaFaceFrownOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceFrownOpen"


class FaFaceFrown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceFrown"


class FaFaceGrimace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrimace"


class FaFaceGrinBeamSweat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinBeamSweat"


class FaFaceGrinBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinBeam"


class FaFaceGrinHearts(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinHearts"


class FaFaceGrinSquintTears(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinSquintTears"


class FaFaceGrinSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinSquint"


class FaFaceGrinStars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinStars"


class FaFaceGrinTears(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinTears"


class FaFaceGrinTongueSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinTongueSquint"


class FaFaceGrinTongueWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinTongueWink"


class FaFaceGrinTongue(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinTongue"


class FaFaceGrinWide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinWide"


class FaFaceGrinWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrinWink"


class FaFaceGrin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceGrin"


class FaFaceKissBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceKissBeam"


class FaFaceKissWinkHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceKissWinkHeart"


class FaFaceKiss(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceKiss"


class FaFaceLaughBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceLaughBeam"


class FaFaceLaughSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceLaughSquint"


class FaFaceLaughWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceLaughWink"


class FaFaceLaugh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceLaugh"


class FaFaceMehBlank(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceMehBlank"


class FaFaceMeh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceMeh"


class FaFaceRollingEyes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceRollingEyes"


class FaFaceSadCry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSadCry"


class FaFaceSadTear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSadTear"


class FaFaceSmileBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSmileBeam"


class FaFaceSmileWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSmileWink"


class FaFaceSmile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSmile"


class FaFaceSurprise(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceSurprise"


class FaFaceTired(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaceTired"


class FaFan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFan"


class FaFaucetDrip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaucetDrip"


class FaFaucet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFaucet"


class FaFax(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFax"


class FaFeatherPointed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFeatherPointed"


class FaFeather(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFeather"


class FaFerry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFerry"


class FaFileArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileArrowDown"


class FaFileArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileArrowUp"


class FaFileAudio(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileAudio"


class FaFileCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCircleCheck"


class FaFileCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCircleExclamation"


class FaFileCircleMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCircleMinus"


class FaFileCirclePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCirclePlus"


class FaFileCircleQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCircleQuestion"


class FaFileCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCircleXmark"


class FaFileCode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCode"


class FaFileContract(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileContract"


class FaFileCsv(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileCsv"


class FaFileExcel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileExcel"


class FaFileExport(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileExport"


class FaFileImage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileImage"


class FaFileImport(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileImport"


class FaFileInvoiceDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileInvoiceDollar"


class FaFileInvoice(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileInvoice"


class FaFileLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileLines"


class FaFileMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileMedical"


class FaFilePdf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilePdf"


class FaFilePen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilePen"


class FaFilePowerpoint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilePowerpoint"


class FaFilePrescription(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilePrescription"


class FaFileShield(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileShield"


class FaFileSignature(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileSignature"


class FaFileVideo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileVideo"


class FaFileWaveform(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileWaveform"


class FaFileWord(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileWord"


class FaFileZipper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFileZipper"


class FaFile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFile"


class FaFillDrip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFillDrip"


class FaFill(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFill"


class FaFilm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilm"


class FaFilterCircleDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilterCircleDollar"


class FaFilterCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilterCircleXmark"


class FaFilter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFilter"


class FaFingerprint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFingerprint"


class FaFireBurner(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFireBurner"


class FaFireExtinguisher(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFireExtinguisher"


class FaFireFlameCurved(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFireFlameCurved"


class FaFireFlameSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFireFlameSimple"


class FaFire(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFire"


class FaFishFins(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFishFins"


class FaFish(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFish"


class FaFlagCheckered(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlagCheckered"


class FaFlagUsa(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlagUsa"


class FaFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlag"


class FaFlaskVial(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlaskVial"


class FaFlask(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlask"


class FaFloppyDisk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFloppyDisk"


class FaFlorinSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFlorinSign"


class FaFolderClosed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolderClosed"


class FaFolderMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolderMinus"


class FaFolderOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolderOpen"


class FaFolderPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolderPlus"


class FaFolderTree(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolderTree"


class FaFolder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFolder"


class FaFont(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFont"


class FaFootball(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFootball"


class FaForwardFast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaForwardFast"


class FaForwardStep(rx.Component):
    library = "react-icons/fa6"
    tag = "FaForwardStep"


class FaForward(rx.Component):
    library = "react-icons/fa6"
    tag = "FaForward"


class FaFrancSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFrancSign"


class FaFrog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFrog"


class FaFutbol(rx.Component):
    library = "react-icons/fa6"
    tag = "FaFutbol"


class FaG(rx.Component):
    library = "react-icons/fa6"
    tag = "FaG"


class FaGamepad(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGamepad"


class FaGasPump(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGasPump"


class FaGaugeHigh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGaugeHigh"


class FaGaugeSimpleHigh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGaugeSimpleHigh"


class FaGaugeSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGaugeSimple"


class FaGauge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGauge"


class FaGavel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGavel"


class FaGear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGear"


class FaGears(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGears"


class FaGem(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGem"


class FaGenderless(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGenderless"


class FaGhost(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGhost"


class FaGift(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGift"


class FaGifts(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGifts"


class FaGlassWaterDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlassWaterDroplet"


class FaGlassWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlassWater"


class FaGlasses(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlasses"


class FaGlobe(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGlobe"


class FaGolfBallTee(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGolfBallTee"


class FaGopuram(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGopuram"


class FaGraduationCap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGraduationCap"


class FaGreaterThanEqual(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGreaterThanEqual"


class FaGreaterThan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGreaterThan"


class FaGripLinesVertical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGripLinesVertical"


class FaGripLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGripLines"


class FaGripVertical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGripVertical"


class FaGrip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGrip"


class FaGroupArrowsRotate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGroupArrowsRotate"


class FaGuaraniSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGuaraniSign"


class FaGuitar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGuitar"


class FaGun(rx.Component):
    library = "react-icons/fa6"
    tag = "FaGun"


class FaH(rx.Component):
    library = "react-icons/fa6"
    tag = "FaH"


class FaHammer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHammer"


class FaHamsa(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHamsa"


class FaHandBackFist(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandBackFist"


class FaHandDots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandDots"


class FaHandFist(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandFist"


class FaHandHoldingDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHoldingDollar"


class FaHandHoldingDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHoldingDroplet"


class FaHandHoldingHand(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHoldingHand"


class FaHandHoldingHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHoldingHeart"


class FaHandHoldingMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHoldingMedical"


class FaHandHolding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandHolding"


class FaHandLizard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandLizard"


class FaHandMiddleFinger(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandMiddleFinger"


class FaHandPeace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPeace"


class FaHandPointDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPointDown"


class FaHandPointLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPointLeft"


class FaHandPointRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPointRight"


class FaHandPointUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPointUp"


class FaHandPointer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandPointer"


class FaHandScissors(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandScissors"


class FaHandSparkles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandSparkles"


class FaHandSpock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandSpock"


class FaHand(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHand"


class FaHandcuffs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandcuffs"


class FaHandsAslInterpreting(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsAslInterpreting"


class FaHandsBound(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsBound"


class FaHandsBubbles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsBubbles"


class FaHandsClapping(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsClapping"


class FaHandsHoldingChild(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsHoldingChild"


class FaHandsHoldingCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsHoldingCircle"


class FaHandsHolding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsHolding"


class FaHandsPraying(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandsPraying"


class FaHands(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHands"


class FaHandshakeAngle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandshakeAngle"


class FaHandshakeSimpleSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandshakeSimpleSlash"


class FaHandshakeSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandshakeSimple"


class FaHandshakeSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandshakeSlash"


class FaHandshake(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHandshake"


class FaHanukiah(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHanukiah"


class FaHardDrive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHardDrive"


class FaHashtag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHashtag"


class FaHatCowboySide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHatCowboySide"


class FaHatCowboy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHatCowboy"


class FaHatWizard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHatWizard"


class FaHeadSideCoughSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadSideCoughSlash"


class FaHeadSideCough(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadSideCough"


class FaHeadSideMask(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadSideMask"


class FaHeadSideVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadSideVirus"


class FaHeading(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeading"


class FaHeadphonesSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadphonesSimple"


class FaHeadphones(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadphones"


class FaHeadset(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeadset"


class FaHeartCircleBolt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCircleBolt"


class FaHeartCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCircleCheck"


class FaHeartCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCircleExclamation"


class FaHeartCircleMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCircleMinus"


class FaHeartCirclePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCirclePlus"


class FaHeartCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCircleXmark"


class FaHeartCrack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartCrack"


class FaHeartPulse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeartPulse"


class FaHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHeart"


class FaHelicopterSymbol(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHelicopterSymbol"


class FaHelicopter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHelicopter"


class FaHelmetSafety(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHelmetSafety"


class FaHelmetUn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHelmetUn"


class FaHighlighter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHighlighter"


class FaHillAvalanche(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHillAvalanche"


class FaHillRockslide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHillRockslide"


class FaHippo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHippo"


class FaHockeyPuck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHockeyPuck"


class FaHollyBerry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHollyBerry"


class FaHorseHead(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHorseHead"


class FaHorse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHorse"


class FaHospitalUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHospitalUser"


class FaHospital(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHospital"


class FaHotTubPerson(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHotTubPerson"


class FaHotdog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHotdog"


class FaHotel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHotel"


class FaHourglassEnd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHourglassEnd"


class FaHourglassHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHourglassHalf"


class FaHourglassStart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHourglassStart"


class FaHourglass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHourglass"


class FaHouseChimneyCrack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseChimneyCrack"


class FaHouseChimneyMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseChimneyMedical"


class FaHouseChimneyUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseChimneyUser"


class FaHouseChimneyWindow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseChimneyWindow"


class FaHouseChimney(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseChimney"


class FaHouseCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseCircleCheck"


class FaHouseCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseCircleExclamation"


class FaHouseCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseCircleXmark"


class FaHouseCrack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseCrack"


class FaHouseFire(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseFire"


class FaHouseFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseFlag"


class FaHouseFloodWaterCircleArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseFloodWaterCircleArrowRight"


class FaHouseFloodWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseFloodWater"


class FaHouseLaptop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseLaptop"


class FaHouseLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseLock"


class FaHouseMedicalCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseMedicalCircleCheck"


class FaHouseMedicalCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseMedicalCircleExclamation"


class FaHouseMedicalCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseMedicalCircleXmark"


class FaHouseMedicalFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseMedicalFlag"


class FaHouseMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseMedical"


class FaHouseSignal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseSignal"


class FaHouseTsunami(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseTsunami"


class FaHouseUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouseUser"


class FaHouse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHouse"


class FaHryvniaSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHryvniaSign"


class FaHurricane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaHurricane"


class FaICursor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaICursor"


class FaI(rx.Component):
    library = "react-icons/fa6"
    tag = "FaI"


class FaIceCream(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIceCream"


class FaIcicles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIcicles"


class FaIcons(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIcons"


class FaIdBadge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIdBadge"


class FaIdCardClip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIdCardClip"


class FaIdCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIdCard"


class FaIgloo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIgloo"


class FaImagePortrait(rx.Component):
    library = "react-icons/fa6"
    tag = "FaImagePortrait"


class FaImage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaImage"


class FaImages(rx.Component):
    library = "react-icons/fa6"
    tag = "FaImages"


class FaInbox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInbox"


class FaIndent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIndent"


class FaIndianRupeeSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIndianRupeeSign"


class FaIndustry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaIndustry"


class FaInfinity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInfinity"


class FaInfo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaInfo"


class FaItalic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaItalic"


class FaJ(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJ"


class FaJarWheat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJarWheat"


class FaJar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJar"


class FaJedi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJedi"


class FaJetFighterUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJetFighterUp"


class FaJetFighter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJetFighter"


class FaJoint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJoint"


class FaJugDetergent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaJugDetergent"


class FaK(rx.Component):
    library = "react-icons/fa6"
    tag = "FaK"


class FaKaaba(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKaaba"


class FaKey(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKey"


class FaKeyboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKeyboard"


class FaKhanda(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKhanda"


class FaKipSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKipSign"


class FaKitMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKitMedical"


class FaKitchenSet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKitchenSet"


class FaKiwiBird(rx.Component):
    library = "react-icons/fa6"
    tag = "FaKiwiBird"


class FaL(rx.Component):
    library = "react-icons/fa6"
    tag = "FaL"


class FaLandMineOn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLandMineOn"


class FaLandmarkDome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLandmarkDome"


class FaLandmarkFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLandmarkFlag"


class FaLandmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLandmark"


class FaLanguage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLanguage"


class FaLaptopCode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLaptopCode"


class FaLaptopFile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLaptopFile"


class FaLaptopMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLaptopMedical"


class FaLaptop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLaptop"


class FaLariSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLariSign"


class FaLayerGroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLayerGroup"


class FaLeaf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLeaf"


class FaLeftLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLeftLong"


class FaLeftRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLeftRight"


class FaLemon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLemon"


class FaLessThanEqual(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLessThanEqual"


class FaLessThan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLessThan"


class FaLifeRing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLifeRing"


class FaLightbulb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLightbulb"


class FaLinesLeaning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinesLeaning"


class FaLinkSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLinkSlash"


class FaLink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLink"


class FaLiraSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLiraSign"


class FaListCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaListCheck"


class FaListOl(rx.Component):
    library = "react-icons/fa6"
    tag = "FaListOl"


class FaListUl(rx.Component):
    library = "react-icons/fa6"
    tag = "FaListUl"


class FaList(rx.Component):
    library = "react-icons/fa6"
    tag = "FaList"


class FaLitecoinSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLitecoinSign"


class FaLocationArrow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocationArrow"


class FaLocationCrosshairs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocationCrosshairs"


class FaLocationDot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocationDot"


class FaLocationPinLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocationPinLock"


class FaLocationPin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocationPin"


class FaLockOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLockOpen"


class FaLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLock"


class FaLocust(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLocust"


class FaLungsVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLungsVirus"


class FaLungs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaLungs"


class FaM(rx.Component):
    library = "react-icons/fa6"
    tag = "FaM"


class FaMagnet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnet"


class FaMagnifyingGlassArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassArrowRight"


class FaMagnifyingGlassChart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassChart"


class FaMagnifyingGlassDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassDollar"


class FaMagnifyingGlassLocation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassLocation"


class FaMagnifyingGlassMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassMinus"


class FaMagnifyingGlassPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlassPlus"


class FaMagnifyingGlass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMagnifyingGlass"


class FaManatSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaManatSign"


class FaMapLocationDot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMapLocationDot"


class FaMapLocation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMapLocation"


class FaMapPin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMapPin"


class FaMap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMap"


class FaMarker(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarker"


class FaMarsAndVenusBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsAndVenusBurst"


class FaMarsAndVenus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsAndVenus"


class FaMarsDouble(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsDouble"


class FaMarsStrokeRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsStrokeRight"


class FaMarsStrokeUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsStrokeUp"


class FaMarsStroke(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMarsStroke"


class FaMars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMars"


class FaMartiniGlassCitrus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMartiniGlassCitrus"


class FaMartiniGlassEmpty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMartiniGlassEmpty"


class FaMartiniGlass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMartiniGlass"


class FaMaskFace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMaskFace"


class FaMaskVentilator(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMaskVentilator"


class FaMask(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMask"


class FaMasksTheater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMasksTheater"


class FaMattressPillow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMattressPillow"


class FaMaximize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMaximize"


class FaMedal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMedal"


class FaMemory(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMemory"


class FaMenorah(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMenorah"


class FaMercury(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMercury"


class FaMessage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMessage"


class FaMeteor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMeteor"


class FaMicrochip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrochip"


class FaMicrophoneLinesSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrophoneLinesSlash"


class FaMicrophoneLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrophoneLines"


class FaMicrophoneSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrophoneSlash"


class FaMicrophone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicrophone"


class FaMicroscope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMicroscope"


class FaMillSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMillSign"


class FaMinimize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMinimize"


class FaMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMinus"


class FaMitten(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMitten"


class FaMobileButton(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMobileButton"


class FaMobileRetro(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMobileRetro"


class FaMobileScreenButton(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMobileScreenButton"


class FaMobileScreen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMobileScreen"


class FaMobile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMobile"


class FaMoneyBill1Wave(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBill1Wave"


class FaMoneyBill1(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBill1"


class FaMoneyBillTransfer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBillTransfer"


class FaMoneyBillTrendUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBillTrendUp"


class FaMoneyBillWave(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBillWave"


class FaMoneyBillWheat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBillWheat"


class FaMoneyBill(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBill"


class FaMoneyBills(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyBills"


class FaMoneyCheckDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyCheckDollar"


class FaMoneyCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoneyCheck"


class FaMonument(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMonument"


class FaMoon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMoon"


class FaMortarPestle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMortarPestle"


class FaMosque(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMosque"


class FaMosquitoNet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMosquitoNet"


class FaMosquito(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMosquito"


class FaMotorcycle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMotorcycle"


class FaMound(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMound"


class FaMountainCity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMountainCity"


class FaMountainSun(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMountainSun"


class FaMountain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMountain"


class FaMugHot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMugHot"


class FaMugSaucer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMugSaucer"


class FaMusic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaMusic"


class FaN(rx.Component):
    library = "react-icons/fa6"
    tag = "FaN"


class FaNairaSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNairaSign"


class FaNetworkWired(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNetworkWired"


class FaNeuter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNeuter"


class FaNewspaper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNewspaper"


class FaNotEqual(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNotEqual"


class FaNotdef(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNotdef"


class FaNoteSticky(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNoteSticky"


class FaNotesMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaNotesMedical"


class FaO(rx.Component):
    library = "react-icons/fa6"
    tag = "FaO"


class FaObjectGroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaObjectGroup"


class FaObjectUngroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaObjectUngroup"


class FaOilCan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOilCan"


class FaOilWell(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOilWell"


class FaOm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOm"


class FaOtter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOtter"


class FaOutdent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaOutdent"


class FaP(rx.Component):
    library = "react-icons/fa6"
    tag = "FaP"


class FaPager(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPager"


class FaPaintRoller(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaintRoller"


class FaPaintbrush(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaintbrush"


class FaPalette(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPalette"


class FaPallet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPallet"


class FaPanorama(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPanorama"


class FaPaperPlane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaperPlane"


class FaPaperclip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaperclip"


class FaParachuteBox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaParachuteBox"


class FaParagraph(rx.Component):
    library = "react-icons/fa6"
    tag = "FaParagraph"


class FaPassport(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPassport"


class FaPaste(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaste"


class FaPause(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPause"


class FaPaw(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPaw"


class FaPeace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeace"


class FaPenClip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPenClip"


class FaPenFancy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPenFancy"


class FaPenNib(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPenNib"


class FaPenRuler(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPenRuler"


class FaPenToSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPenToSquare"


class FaPen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPen"


class FaPencil(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPencil"


class FaPeopleArrows(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleArrows"


class FaPeopleCarryBox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleCarryBox"


class FaPeopleGroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleGroup"


class FaPeopleLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleLine"


class FaPeoplePulling(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeoplePulling"


class FaPeopleRobbery(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleRobbery"


class FaPeopleRoof(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPeopleRoof"


class FaPepperHot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPepperHot"


class FaPercent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPercent"


class FaPersonArrowDownToLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonArrowDownToLine"


class FaPersonArrowUpFromLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonArrowUpFromLine"


class FaPersonBiking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonBiking"


class FaPersonBooth(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonBooth"


class FaPersonBreastfeeding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonBreastfeeding"


class FaPersonBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonBurst"


class FaPersonCane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCane"


class FaPersonChalkboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonChalkboard"


class FaPersonCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCircleCheck"


class FaPersonCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCircleExclamation"


class FaPersonCircleMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCircleMinus"


class FaPersonCirclePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCirclePlus"


class FaPersonCircleQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCircleQuestion"


class FaPersonCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonCircleXmark"


class FaPersonDigging(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonDigging"


class FaPersonDotsFromLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonDotsFromLine"


class FaPersonDressBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonDressBurst"


class FaPersonDress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonDress"


class FaPersonDrowning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonDrowning"


class FaPersonFallingBurst(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonFallingBurst"


class FaPersonFalling(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonFalling"


class FaPersonHalfDress(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonHalfDress"


class FaPersonHarassing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonHarassing"


class FaPersonHiking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonHiking"


class FaPersonMilitaryPointing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonMilitaryPointing"


class FaPersonMilitaryRifle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonMilitaryRifle"


class FaPersonMilitaryToPerson(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonMilitaryToPerson"


class FaPersonPraying(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonPraying"


class FaPersonPregnant(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonPregnant"


class FaPersonRays(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonRays"


class FaPersonRifle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonRifle"


class FaPersonRunning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonRunning"


class FaPersonShelter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonShelter"


class FaPersonSkating(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonSkating"


class FaPersonSkiingNordic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonSkiingNordic"


class FaPersonSkiing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonSkiing"


class FaPersonSnowboarding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonSnowboarding"


class FaPersonSwimming(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonSwimming"


class FaPersonThroughWindow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonThroughWindow"


class FaPersonWalkingArrowLoopLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalkingArrowLoopLeft"


class FaPersonWalkingArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalkingArrowRight"


class FaPersonWalkingDashedLineArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalkingDashedLineArrowRight"


class FaPersonWalkingLuggage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalkingLuggage"


class FaPersonWalkingWithCane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalkingWithCane"


class FaPersonWalking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPersonWalking"


class FaPerson(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPerson"


class FaPesetaSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPesetaSign"


class FaPesoSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPesoSign"


class FaPhoneFlip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhoneFlip"


class FaPhoneSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhoneSlash"


class FaPhoneVolume(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhoneVolume"


class FaPhone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhone"


class FaPhotoFilm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPhotoFilm"


class FaPiggyBank(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPiggyBank"


class FaPills(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPills"


class FaPizzaSlice(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPizzaSlice"


class FaPlaceOfWorship(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaceOfWorship"


class FaPlaneArrival(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneArrival"


class FaPlaneCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneCircleCheck"


class FaPlaneCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneCircleExclamation"


class FaPlaneCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneCircleXmark"


class FaPlaneDeparture(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneDeparture"


class FaPlaneLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneLock"


class FaPlaneSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneSlash"


class FaPlaneUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlaneUp"


class FaPlane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlane"


class FaPlantWilt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlantWilt"


class FaPlateWheat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlateWheat"


class FaPlay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlay"


class FaPlugCircleBolt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCircleBolt"


class FaPlugCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCircleCheck"


class FaPlugCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCircleExclamation"


class FaPlugCircleMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCircleMinus"


class FaPlugCirclePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCirclePlus"


class FaPlugCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlugCircleXmark"


class FaPlug(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlug"


class FaPlusMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlusMinus"


class FaPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPlus"


class FaPodcast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPodcast"


class FaPooStorm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPooStorm"


class FaPoo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPoo"


class FaPoop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPoop"


class FaPowerOff(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPowerOff"


class FaPrescriptionBottleMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPrescriptionBottleMedical"


class FaPrescriptionBottle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPrescriptionBottle"


class FaPrescription(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPrescription"


class FaPrint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPrint"


class FaPumpMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPumpMedical"


class FaPumpSoap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPumpSoap"


class FaPuzzlePiece(rx.Component):
    library = "react-icons/fa6"
    tag = "FaPuzzlePiece"


class FaQ(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQ"


class FaQrcode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQrcode"


class FaQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQuestion"


class FaQuoteLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQuoteLeft"


class FaQuoteRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaQuoteRight"


class FaR(rx.Component):
    library = "react-icons/fa6"
    tag = "FaR"


class FaRadiation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRadiation"


class FaRadio(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRadio"


class FaRainbow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRainbow"


class FaRankingStar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRankingStar"


class FaReceipt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReceipt"


class FaRecordVinyl(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRecordVinyl"


class FaRectangleAd(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRectangleAd"


class FaRectangleList(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRectangleList"


class FaRectangleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRectangleXmark"


class FaRecycle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRecycle"


class FaRegistered(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegistered"


class FaRepeat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRepeat"


class FaReplyAll(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReplyAll"


class FaReply(rx.Component):
    library = "react-icons/fa6"
    tag = "FaReply"


class FaRepublican(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRepublican"


class FaRestroom(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRestroom"


class FaRetweet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRetweet"


class FaRibbon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRibbon"


class FaRightFromBracket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRightFromBracket"


class FaRightLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRightLeft"


class FaRightLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRightLong"


class FaRightToBracket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRightToBracket"


class FaRing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRing"


class FaRoadBarrier(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadBarrier"


class FaRoadBridge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadBridge"


class FaRoadCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadCircleCheck"


class FaRoadCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadCircleExclamation"


class FaRoadCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadCircleXmark"


class FaRoadLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadLock"


class FaRoadSpikes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoadSpikes"


class FaRoad(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoad"


class FaRobot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRobot"


class FaRocket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRocket"


class FaRotateLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRotateLeft"


class FaRotateRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRotateRight"


class FaRotate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRotate"


class FaRoute(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRoute"


class FaRss(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRss"


class FaRubleSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRubleSign"


class FaRug(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRug"


class FaRulerCombined(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRulerCombined"


class FaRulerHorizontal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRulerHorizontal"


class FaRulerVertical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRulerVertical"


class FaRuler(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRuler"


class FaRupeeSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRupeeSign"


class FaRupiahSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRupiahSign"


class FaS(rx.Component):
    library = "react-icons/fa6"
    tag = "FaS"


class FaSackDollar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSackDollar"


class FaSackXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSackXmark"


class FaSailboat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSailboat"


class FaSatelliteDish(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSatelliteDish"


class FaSatellite(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSatellite"


class FaScaleBalanced(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScaleBalanced"


class FaScaleUnbalancedFlip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScaleUnbalancedFlip"


class FaScaleUnbalanced(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScaleUnbalanced"


class FaSchoolCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchoolCircleCheck"


class FaSchoolCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchoolCircleExclamation"


class FaSchoolCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchoolCircleXmark"


class FaSchoolFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchoolFlag"


class FaSchoolLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchoolLock"


class FaSchool(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSchool"


class FaScissors(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScissors"


class FaScrewdriverWrench(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScrewdriverWrench"


class FaScrewdriver(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScrewdriver"


class FaScrollTorah(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScrollTorah"


class FaScroll(rx.Component):
    library = "react-icons/fa6"
    tag = "FaScroll"


class FaSdCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSdCard"


class FaSection(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSection"


class FaSeedling(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSeedling"


class FaServer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaServer"


class FaShapes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShapes"


class FaShareFromSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShareFromSquare"


class FaShareNodes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShareNodes"


class FaShare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShare"


class FaSheetPlastic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSheetPlastic"


class FaShekelSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShekelSign"


class FaShieldCat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShieldCat"


class FaShieldDog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShieldDog"


class FaShieldHalved(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShieldHalved"


class FaShieldHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShieldHeart"


class FaShieldVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShieldVirus"


class FaShield(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShield"


class FaShip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShip"


class FaShirt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShirt"


class FaShoePrints(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShoePrints"


class FaShopLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShopLock"


class FaShopSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShopSlash"


class FaShop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShop"


class FaShower(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShower"


class FaShrimp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShrimp"


class FaShuffle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShuffle"


class FaShuttleSpace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaShuttleSpace"


class FaSignHanging(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSignHanging"


class FaSignal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSignal"


class FaSignature(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSignature"


class FaSignsPost(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSignsPost"


class FaSimCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSimCard"


class FaSink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSink"


class FaSitemap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSitemap"


class FaSkullCrossbones(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSkullCrossbones"


class FaSkull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSkull"


class FaSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSlash"


class FaSleigh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSleigh"


class FaSliders(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSliders"


class FaSmog(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSmog"


class FaSmoking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSmoking"


class FaSnowflake(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSnowflake"


class FaSnowman(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSnowman"


class FaSnowplow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSnowplow"


class FaSoap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSoap"


class FaSocks(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSocks"


class FaSolarPanel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSolarPanel"


class FaSortDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSortDown"


class FaSortUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSortUp"


class FaSort(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSort"


class FaSpa(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpa"


class FaSpaghettiMonsterFlying(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpaghettiMonsterFlying"


class FaSpellCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpellCheck"


class FaSpider(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpider"


class FaSpinner(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpinner"


class FaSplotch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSplotch"


class FaSpoon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSpoon"


class FaSprayCanSparkles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSprayCanSparkles"


class FaSprayCan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSprayCan"


class FaSquareArrowUpRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareArrowUpRight"


class FaSquareCaretDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareCaretDown"


class FaSquareCaretLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareCaretLeft"


class FaSquareCaretRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareCaretRight"


class FaSquareCaretUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareCaretUp"


class FaSquareCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareCheck"


class FaSquareEnvelope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareEnvelope"


class FaSquareFull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareFull"


class FaSquareH(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareH"


class FaSquareMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareMinus"


class FaSquareNfi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareNfi"


class FaSquareParking(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareParking"


class FaSquarePen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePen"


class FaSquarePersonConfined(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePersonConfined"


class FaSquarePhoneFlip(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePhoneFlip"


class FaSquarePhone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePhone"


class FaSquarePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePlus"


class FaSquarePollHorizontal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePollHorizontal"


class FaSquarePollVertical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquarePollVertical"


class FaSquareRootVariable(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareRootVariable"


class FaSquareRss(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareRss"


class FaSquareShareNodes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareShareNodes"


class FaSquareUpRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareUpRight"


class FaSquareVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareVirus"


class FaSquareXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquareXmark"


class FaSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSquare"


class FaStaffSnake(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStaffSnake"


class FaStairs(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStairs"


class FaStamp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStamp"


class FaStapler(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStapler"


class FaStarAndCrescent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStarAndCrescent"


class FaStarHalfStroke(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStarHalfStroke"


class FaStarHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStarHalf"


class FaStarOfDavid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStarOfDavid"


class FaStarOfLife(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStarOfLife"


class FaStar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStar"


class FaSterlingSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSterlingSign"


class FaStethoscope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStethoscope"


class FaStop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStop"


class FaStopwatch20(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStopwatch20"


class FaStopwatch(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStopwatch"


class FaStoreSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStoreSlash"


class FaStore(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStore"


class FaStreetView(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStreetView"


class FaStrikethrough(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStrikethrough"


class FaStroopwafel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaStroopwafel"


class FaSubscript(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSubscript"


class FaSuitcaseMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuitcaseMedical"


class FaSuitcaseRolling(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuitcaseRolling"


class FaSuitcase(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuitcase"


class FaSunPlantWilt(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSunPlantWilt"


class FaSun(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSun"


class FaSuperscript(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSuperscript"


class FaSwatchbook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSwatchbook"


class FaSynagogue(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSynagogue"


class FaSyringe(rx.Component):
    library = "react-icons/fa6"
    tag = "FaSyringe"


class FaT(rx.Component):
    library = "react-icons/fa6"
    tag = "FaT"


class FaTableCellsLarge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTableCellsLarge"


class FaTableCells(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTableCells"


class FaTableColumns(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTableColumns"


class FaTableList(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTableList"


class FaTableTennisPaddleBall(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTableTennisPaddleBall"


class FaTable(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTable"


class FaTabletButton(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTabletButton"


class FaTabletScreenButton(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTabletScreenButton"


class FaTablet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTablet"


class FaTablets(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTablets"


class FaTachographDigital(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTachographDigital"


class FaTag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTag"


class FaTags(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTags"


class FaTape(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTape"


class FaTarpDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTarpDroplet"


class FaTarp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTarp"


class FaTaxi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTaxi"


class FaTeethOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTeethOpen"


class FaTeeth(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTeeth"


class FaTemperatureArrowDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureArrowDown"


class FaTemperatureArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureArrowUp"


class FaTemperatureEmpty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureEmpty"


class FaTemperatureFull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureFull"


class FaTemperatureHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureHalf"


class FaTemperatureHigh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureHigh"


class FaTemperatureLow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureLow"


class FaTemperatureQuarter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureQuarter"


class FaTemperatureThreeQuarters(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTemperatureThreeQuarters"


class FaTengeSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTengeSign"


class FaTentArrowDownToLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTentArrowDownToLine"


class FaTentArrowLeftRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTentArrowLeftRight"


class FaTentArrowTurnLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTentArrowTurnLeft"


class FaTentArrowsDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTentArrowsDown"


class FaTent(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTent"


class FaTents(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTents"


class FaTerminal(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTerminal"


class FaTextHeight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTextHeight"


class FaTextSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTextSlash"


class FaTextWidth(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTextWidth"


class FaThermometer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThermometer"


class FaThumbsDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThumbsDown"


class FaThumbsUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThumbsUp"


class FaThumbtack(rx.Component):
    library = "react-icons/fa6"
    tag = "FaThumbtack"


class FaTicketSimple(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTicketSimple"


class FaTicket(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTicket"


class FaTimeline(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTimeline"


class FaToggleOff(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToggleOff"


class FaToggleOn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToggleOn"


class FaToiletPaperSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToiletPaperSlash"


class FaToiletPaper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToiletPaper"


class FaToiletPortable(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToiletPortable"


class FaToilet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToilet"


class FaToiletsPortable(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToiletsPortable"


class FaToolbox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToolbox"


class FaTooth(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTooth"


class FaToriiGate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaToriiGate"


class FaTornado(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTornado"


class FaTowerBroadcast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTowerBroadcast"


class FaTowerCell(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTowerCell"


class FaTowerObservation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTowerObservation"


class FaTractor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTractor"


class FaTrademark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrademark"


class FaTrafficLight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrafficLight"


class FaTrailer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrailer"


class FaTrainSubway(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrainSubway"


class FaTrainTram(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrainTram"


class FaTrain(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrain"


class FaTransgender(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTransgender"


class FaTrashArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrashArrowUp"


class FaTrashCanArrowUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrashCanArrowUp"


class FaTrashCan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrashCan"


class FaTrash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrash"


class FaTreeCity(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTreeCity"


class FaTree(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTree"


class FaTriangleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTriangleExclamation"


class FaTrophy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrophy"


class FaTrowelBricks(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrowelBricks"


class FaTrowel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTrowel"


class FaTruckArrowRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckArrowRight"


class FaTruckDroplet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckDroplet"


class FaTruckFast(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckFast"


class FaTruckFieldUn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckFieldUn"


class FaTruckField(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckField"


class FaTruckFront(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckFront"


class FaTruckMedical(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckMedical"


class FaTruckMonster(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckMonster"


class FaTruckMoving(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckMoving"


class FaTruckPickup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckPickup"


class FaTruckPlane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckPlane"


class FaTruckRampBox(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruckRampBox"


class FaTruck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTruck"


class FaTty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTty"


class FaTurkishLiraSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTurkishLiraSign"


class FaTurnDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTurnDown"


class FaTurnUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTurnUp"


class FaTv(rx.Component):
    library = "react-icons/fa6"
    tag = "FaTv"


class FaU(rx.Component):
    library = "react-icons/fa6"
    tag = "FaU"


class FaUmbrellaBeach(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUmbrellaBeach"


class FaUmbrella(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUmbrella"


class FaUnderline(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUnderline"


class FaUniversalAccess(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUniversalAccess"


class FaUnlockKeyhole(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUnlockKeyhole"


class FaUnlock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUnlock"


class FaUpDownLeftRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpDownLeftRight"


class FaUpDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpDown"


class FaUpLong(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpLong"


class FaUpRightAndDownLeftFromCenter(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpRightAndDownLeftFromCenter"


class FaUpRightFromSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpRightFromSquare"


class FaUpload(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUpload"


class FaUserAstronaut(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserAstronaut"


class FaUserCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserCheck"


class FaUserClock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserClock"


class FaUserDoctor(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserDoctor"


class FaUserGear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserGear"


class FaUserGraduate(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserGraduate"


class FaUserGroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserGroup"


class FaUserInjured(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserInjured"


class FaUserLargeSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserLargeSlash"


class FaUserLarge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserLarge"


class FaUserLock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserLock"


class FaUserMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserMinus"


class FaUserNinja(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserNinja"


class FaUserNurse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserNurse"


class FaUserPen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserPen"


class FaUserPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserPlus"


class FaUserSecret(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserSecret"


class FaUserShield(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserShield"


class FaUserSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserSlash"


class FaUserTag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserTag"


class FaUserTie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserTie"


class FaUserXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUserXmark"


class FaUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUser"


class FaUsersBetweenLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersBetweenLines"


class FaUsersGear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersGear"


class FaUsersLine(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersLine"


class FaUsersRays(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersRays"


class FaUsersRectangle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersRectangle"


class FaUsersSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersSlash"


class FaUsersViewfinder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsersViewfinder"


class FaUsers(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUsers"


class FaUtensils(rx.Component):
    library = "react-icons/fa6"
    tag = "FaUtensils"


class FaV(rx.Component):
    library = "react-icons/fa6"
    tag = "FaV"


class FaVanShuttle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVanShuttle"


class FaVault(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVault"


class FaVectorSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVectorSquare"


class FaVenusDouble(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVenusDouble"


class FaVenusMars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVenusMars"


class FaVenus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVenus"


class FaVestPatches(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVestPatches"


class FaVest(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVest"


class FaVialCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVialCircleCheck"


class FaVialVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVialVirus"


class FaVial(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVial"


class FaVials(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVials"


class FaVideoSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVideoSlash"


class FaVideo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVideo"


class FaVihara(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVihara"


class FaVirusCovidSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVirusCovidSlash"


class FaVirusCovid(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVirusCovid"


class FaVirusSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVirusSlash"


class FaVirus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVirus"


class FaViruses(rx.Component):
    library = "react-icons/fa6"
    tag = "FaViruses"


class FaVoicemail(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVoicemail"


class FaVolcano(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolcano"


class FaVolleyball(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolleyball"


class FaVolumeHigh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolumeHigh"


class FaVolumeLow(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolumeLow"


class FaVolumeOff(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolumeOff"


class FaVolumeXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVolumeXmark"


class FaVrCardboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaVrCardboard"


class FaW(rx.Component):
    library = "react-icons/fa6"
    tag = "FaW"


class FaWalkieTalkie(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWalkieTalkie"


class FaWallet(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWallet"


class FaWandMagicSparkles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWandMagicSparkles"


class FaWandMagic(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWandMagic"


class FaWandSparkles(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWandSparkles"


class FaWarehouse(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWarehouse"


class FaWaterLadder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWaterLadder"


class FaWater(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWater"


class FaWaveSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWaveSquare"


class FaWeightHanging(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWeightHanging"


class FaWeightScale(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWeightScale"


class FaWheatAwnCircleExclamation(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWheatAwnCircleExclamation"


class FaWheatAwn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWheatAwn"


class FaWheelchairMove(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWheelchairMove"


class FaWheelchair(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWheelchair"


class FaWhiskeyGlass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWhiskeyGlass"


class FaWifi(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWifi"


class FaWind(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWind"


class FaWindowMaximize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWindowMaximize"


class FaWindowMinimize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWindowMinimize"


class FaWindowRestore(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWindowRestore"


class FaWineBottle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWineBottle"


class FaWineGlassEmpty(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWineGlassEmpty"


class FaWineGlass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWineGlass"


class FaWonSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWonSign"


class FaWorm(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWorm"


class FaWrench(rx.Component):
    library = "react-icons/fa6"
    tag = "FaWrench"


class FaXRay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaXRay"


class FaX(rx.Component):
    library = "react-icons/fa6"
    tag = "FaX"


class FaXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaXmark"


class FaXmarksLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaXmarksLines"


class FaY(rx.Component):
    library = "react-icons/fa6"
    tag = "FaY"


class FaYenSign(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYenSign"


class FaYinYang(rx.Component):
    library = "react-icons/fa6"
    tag = "FaYinYang"


class FaZ(rx.Component):
    library = "react-icons/fa6"
    tag = "FaZ"


class FaRegAddressBook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegAddressBook"


class FaRegAddressCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegAddressCard"


class FaRegBellSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegBellSlash"


class FaRegBell(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegBell"


class FaRegBookmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegBookmark"


class FaRegBuilding(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegBuilding"


class FaRegCalendarCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendarCheck"


class FaRegCalendarDays(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendarDays"


class FaRegCalendarMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendarMinus"


class FaRegCalendarPlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendarPlus"


class FaRegCalendarXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendarXmark"


class FaRegCalendar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCalendar"


class FaRegChartBar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChartBar"


class FaRegChessBishop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessBishop"


class FaRegChessKing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessKing"


class FaRegChessKnight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessKnight"


class FaRegChessPawn(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessPawn"


class FaRegChessQueen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessQueen"


class FaRegChessRook(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegChessRook"


class FaRegCircleCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleCheck"


class FaRegCircleDot(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleDot"


class FaRegCircleDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleDown"


class FaRegCircleLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleLeft"


class FaRegCirclePause(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCirclePause"


class FaRegCirclePlay(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCirclePlay"


class FaRegCircleQuestion(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleQuestion"


class FaRegCircleRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleRight"


class FaRegCircleStop(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleStop"


class FaRegCircleUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleUp"


class FaRegCircleUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleUser"


class FaRegCircleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircleXmark"


class FaRegCircle(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCircle"


class FaRegClipboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegClipboard"


class FaRegClock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegClock"


class FaRegClone(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegClone"


class FaRegClosedCaptioning(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegClosedCaptioning"


class FaRegCommentDots(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCommentDots"


class FaRegComment(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegComment"


class FaRegComments(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegComments"


class FaRegCompass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCompass"


class FaRegCopy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCopy"


class FaRegCopyright(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCopyright"


class FaRegCreditCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegCreditCard"


class FaRegEnvelopeOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegEnvelopeOpen"


class FaRegEnvelope(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegEnvelope"


class FaRegEyeSlash(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegEyeSlash"


class FaRegEye(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegEye"


class FaRegFaceAngry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceAngry"


class FaRegFaceDizzy(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceDizzy"


class FaRegFaceFlushed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceFlushed"


class FaRegFaceFrownOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceFrownOpen"


class FaRegFaceFrown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceFrown"


class FaRegFaceGrimace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrimace"


class FaRegFaceGrinBeamSweat(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinBeamSweat"


class FaRegFaceGrinBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinBeam"


class FaRegFaceGrinHearts(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinHearts"


class FaRegFaceGrinSquintTears(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinSquintTears"


class FaRegFaceGrinSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinSquint"


class FaRegFaceGrinStars(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinStars"


class FaRegFaceGrinTears(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinTears"


class FaRegFaceGrinTongueSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinTongueSquint"


class FaRegFaceGrinTongueWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinTongueWink"


class FaRegFaceGrinTongue(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinTongue"


class FaRegFaceGrinWide(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinWide"


class FaRegFaceGrinWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrinWink"


class FaRegFaceGrin(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceGrin"


class FaRegFaceKissBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceKissBeam"


class FaRegFaceKissWinkHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceKissWinkHeart"


class FaRegFaceKiss(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceKiss"


class FaRegFaceLaughBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceLaughBeam"


class FaRegFaceLaughSquint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceLaughSquint"


class FaRegFaceLaughWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceLaughWink"


class FaRegFaceLaugh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceLaugh"


class FaRegFaceMehBlank(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceMehBlank"


class FaRegFaceMeh(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceMeh"


class FaRegFaceRollingEyes(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceRollingEyes"


class FaRegFaceSadCry(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSadCry"


class FaRegFaceSadTear(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSadTear"


class FaRegFaceSmileBeam(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSmileBeam"


class FaRegFaceSmileWink(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSmileWink"


class FaRegFaceSmile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSmile"


class FaRegFaceSurprise(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceSurprise"


class FaRegFaceTired(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFaceTired"


class FaRegFileAudio(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileAudio"


class FaRegFileCode(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileCode"


class FaRegFileExcel(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileExcel"


class FaRegFileImage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileImage"


class FaRegFileLines(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileLines"


class FaRegFilePdf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFilePdf"


class FaRegFilePowerpoint(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFilePowerpoint"


class FaRegFileVideo(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileVideo"


class FaRegFileWord(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileWord"


class FaRegFileZipper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFileZipper"


class FaRegFile(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFile"


class FaRegFlag(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFlag"


class FaRegFloppyDisk(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFloppyDisk"


class FaRegFolderClosed(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFolderClosed"


class FaRegFolderOpen(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFolderOpen"


class FaRegFolder(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFolder"


class FaRegFontAwesome(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFontAwesome"


class FaRegFutbol(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegFutbol"


class FaRegGem(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegGem"


class FaRegHandBackFist(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandBackFist"


class FaRegHandLizard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandLizard"


class FaRegHandPeace(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPeace"


class FaRegHandPointDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPointDown"


class FaRegHandPointLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPointLeft"


class FaRegHandPointRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPointRight"


class FaRegHandPointUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPointUp"


class FaRegHandPointer(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandPointer"


class FaRegHandScissors(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandScissors"


class FaRegHandSpock(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandSpock"


class FaRegHand(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHand"


class FaRegHandshake(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHandshake"


class FaRegHardDrive(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHardDrive"


class FaRegHeart(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHeart"


class FaRegHospital(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHospital"


class FaRegHourglassHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHourglassHalf"


class FaRegHourglass(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegHourglass"


class FaRegIdBadge(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegIdBadge"


class FaRegIdCard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegIdCard"


class FaRegImage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegImage"


class FaRegImages(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegImages"


class FaRegKeyboard(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegKeyboard"


class FaRegLemon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegLemon"


class FaRegLifeRing(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegLifeRing"


class FaRegLightbulb(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegLightbulb"


class FaRegMap(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegMap"


class FaRegMessage(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegMessage"


class FaRegMoneyBill1(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegMoneyBill1"


class FaRegMoon(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegMoon"


class FaRegNewspaper(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegNewspaper"


class FaRegNoteSticky(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegNoteSticky"


class FaRegObjectGroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegObjectGroup"


class FaRegObjectUngroup(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegObjectUngroup"


class FaRegPaperPlane(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegPaperPlane"


class FaRegPaste(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegPaste"


class FaRegPenToSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegPenToSquare"


class FaRegRectangleList(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegRectangleList"


class FaRegRectangleXmark(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegRectangleXmark"


class FaRegRegistered(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegRegistered"


class FaRegShareFromSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegShareFromSquare"


class FaRegSnowflake(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSnowflake"


class FaRegSquareCaretDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareCaretDown"


class FaRegSquareCaretLeft(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareCaretLeft"


class FaRegSquareCaretRight(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareCaretRight"


class FaRegSquareCaretUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareCaretUp"


class FaRegSquareCheck(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareCheck"


class FaRegSquareFull(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareFull"


class FaRegSquareMinus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquareMinus"


class FaRegSquarePlus(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquarePlus"


class FaRegSquare(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSquare"


class FaRegStarHalfStroke(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegStarHalfStroke"


class FaRegStarHalf(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegStarHalf"


class FaRegStar(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegStar"


class FaRegSun(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegSun"


class FaRegThumbsDown(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegThumbsDown"


class FaRegThumbsUp(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegThumbsUp"


class FaRegTrashCan(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegTrashCan"


class FaRegUser(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegUser"


class FaRegWindowMaximize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegWindowMaximize"


class FaRegWindowMinimize(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegWindowMinimize"


class FaRegWindowRestore(rx.Component):
    library = "react-icons/fa6"
    tag = "FaRegWindowRestore"


